==> wine-0.9.16.tar.bz2: wine-0.9.16/dlls/mshtml/resource.h <==
/*
 * Copyright 2005 Jacek Caban
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#define IDS_HTMLDISABLED    7500
#define IDS_HTMLDOCUMENT    7501
#define IDS_DOWNLOADING     7502
#define IDS_INSTALLING      7503

#define ID_DWL_DIALOG       7600
#define ID_DWL_PROGRESS     7601
#define ID_DWL_INSTALL      7602
#define ID_DWL_STATUS       7603

#define IDR_BROWSE_CONTEXT_MENU  24641

#define IDM_COPY        15
#define IDM_CUT         16
#define IDM_DELETE      17

#define IDM_PASTE       26
#define IDM_PRINT       27
#define IDM_PROPERTIES  28

#define IDM_SELECTALL   31

#define IDM_UNDO        43

#define IDM_BROWSEVIEW          2126
#define IDM_EDITVIEW            2127

#define IDM_OPENLINK            2136
#define IDM_OPENINNEWWINDOW     2137

#define IDM_VIEWSOURCE          2139

#define IDM_CELL                2206
#define IDM_ROW                 2207
#define IDM_COLUMN              2208
#define IDM_TABLE               2209
#define IDM_TABLEPROPERTIES     2210
#define IDM_CELLPROPERTIES      2211

#define IDM_ADDTOFAVOURITES     2261
#define IDM_COPYSHORTCUT        2262
#define IDM_SAVEBACKGROUNDAS    2263
#define IDM_SETASBACKGROUND     2264
#define IDM_COPYBACKGROUND      2265
#define IDM_CREATESHORTCUT      2266

#define IDM_SAVETARGETAS        2268
#define IDM_SHOWPICTURE         2269
#define IDM_SAVEPICTUREAS       2270
#define IDM_PLAY                2271
#define IDM_STOP                2272
#define IDM_PRINTTARGET         2273

#define IDM_REWIND              2276

#define IDM_SETASDESKTOPITEM    2278

#define IDM_BACK                2282
#define IDM_FORWARD             2283

#define IDM_GOTOMYPICTURES      2287
#define IDM_EMAILPICTURE        2288
#define IDM_PRINTPICTURE        2289

#define IDM_ENCODING            2292

#define IDM_SCROLLHERE          2380
#define IDM_TOP                 2381
#define IDM_BOTTOM              2382
#define IDM_PAGEUP              2383
#define IDM_PAGEDOWN            2384
#define IDM_SCROLLUP            2385
#define IDM_SCROLLDOWN          2386
#define IDM_LEFTEDGE            2387
#define IDM_RIGHTEDGE           2388
#define IDM_PAGELEFT            2389
#define IDM_PAGERIGHT           2390
#define IDM_SCROLLLEFT          2391
#define IDM_SCROLLRIGHT         2392

#define IDM_TRACETAGS           6004
#define IDM_RESOURCEFAILURES    6005
#define IDM_DUMPTRACKINGINFO    6006
#define IDM_DEBUGBREAK          6007
#define IDM_DEBUGVIEW           6008
#define IDM_DUMPTREE            6009
#define IDM_DUMPLINES           6010

#define IDM_SAVEHTML            6012
#define IDM_MEMORYMONITOR       6013
#define IDM_PERFORMANCEMETERS   6014
#define IDM_DUMPDISPLAYTREE     6015
#define IDM_DUMPFORMATCACHES    6016
#define IDM_DUMPLAYOUTRECTS     6017

#define IDM_REFRESH             6042

==> wine-0.9.31.tar.bz2: wine-0.9.31/dlls/mshtml/resource.h <==
/*
 * Copyright 2005 Jacek Caban
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#define IDS_HTMLDISABLED    7500
#define IDS_HTMLDOCUMENT    7501
#define IDS_DOWNLOADING     7502
#define IDS_INSTALLING      7503

#define ID_DWL_DIALOG       7600
#define ID_DWL_PROGRESS     7601
#define ID_DWL_INSTALL      7602
#define ID_DWL_STATUS       7603

#define IDS_MESSAGE_BOX_TITLE  2213

#define IDS_PRINT_HEADER_TEMPLATE  8403
#define IDS_PRINT_FOOTER_TEMPLATE  8404

#define IDR_BROWSE_CONTEXT_MENU  24641

#define IDM_TRACETAGS           6004
#define IDM_RESOURCEFAILURES    6005
#define IDM_DUMPTRACKINGINFO    6006
#define IDM_DEBUGBREAK          6007
#define IDM_DEBUGVIEW           6008
#define IDM_DUMPTREE            6009
#define IDM_DUMPLINES           6010

#define IDM_SAVEHTML            6012
#define IDM_MEMORYMONITOR       6013
#define IDM_PERFORMANCEMETERS   6014
#define IDM_DUMPDISPLAYTREE     6015
#define IDM_DUMPFORMATCACHES    6016
#define IDM_DUMPLAYOUTRECTS     6017

#define _IDM_REFRESH            6042
